@@ -22,6 +22,7 @@ with requests.Session() as session:
     user_info = None
     tags = []
 
+
     def set_api_key(api_key):
         user_api_key = api_key
 
@@ -29,13 +30,16 @@ with requests.Session() as session:
             'Authorization': f'X-API-KEY {user_api_key}'
         })
 
+
     def set_user(user):
         user_info = user
 
+
     def set_tag(property_name, property_value):
         tags.append({property_name: property_value})
 
-    def info(message, event_time_required = False):
+
+    def info(message, event_time_required=False):
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         print('installed_packages => ', installed_packages)
 
@@ -79,12 +83,13 @@ with requests.Session() as session:
             sourceFilePath,
             eventTime,
             message,
-            json.dumps(vars(tags)),
+            json.dumps(tags),
             json.dumps(vars(detail))
         ))
 
-    def error(occurred_error, event_time_required = False):
-        message = json.dumps(vars(occurred_error))
+
+    def error(occurred_error, event_time_required=False):
+        message = json.dumps(occurred_error)
 
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         print('installed_packages => ', installed_packages)
@@ -133,6 +138,7 @@ with requests.Session() as session:
             json.dumps(vars(detail))
         ))
 
+
     def create_log(payload):
         response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
                                 data=json.dumps(vars(payload)))
